# Table of contents

* [Introduction](./README.md)
* [Setup and maintenance](./setup/README.md)
  * [Updating from Misago 0.5](./setup/UpdatingFrom05.md)
  * [Update paths](./setup/UpdatePaths.md)
* [Settings](./settings/README.md)
  * [Core settings](./settings/Core.md)
  * [Database settings](./settings/Database.md)
* [Coding style](./CodingStyle.md)
* [Social authentication](./SocialAuth.md)
* [User rank styles](./UserRankStyles.md)
* [Category styles](./CategoryStyles.md)
* [User authentication](./Auth.md)
* [Writing new admin actions](./WritingNewAdminActions.md)
* [Permissions framework](./PermissionsFramework.md)
* [View decorators](./Decorators.md)
* [Context processors](./ContextProcessors.md)
* [Frontend context](./FrontendContext.md)
* [Forms](./Forms.md)
* [Cache](./Cache.md)
* [Sending mails](./Mails.md)
* [Markup](./Markup.md)
* [Posting process](./PostingProcess.md)
* [Profile fields](./ProfileFields.md)
* [Threads types](./ThreadTypes.md)
* [Extending pages](./ExtendingPages.md)
* [Validating registrations](./ValidatingRegistrations.md)
* [Validators](./Validators.md)
* [Search filters](./SearchFilters.md)
* [Template tags](./TemplateTags.md)
* [Shortcuts](./Shortcuts.md)
* [Thread store](./ThreadStore.md)
* [View errors](./ViewErrors.md)